@@ -7,7 +7,7 @@ package Lemonldap::NG::Portal::UserDBMulti;
 
 use Lemonldap::NG::Portal::_Multi;    #inherits
 
-our $VERSION = '1.2.2_01';
+our $VERSION = '1.4.0';
 
 sub userDBInit {
     my $self = shift;
@@ -29,5 +29,10 @@ sub setGroups {
     return $self->_multi->try( 'setGroups', 1 );
 }
 
+sub userDBFinish {
+    my $self = shift;
+    return $self->_multi->try( 'userDBFinish', 1 );
+}
+
 1;
 
